/*
 * Contact.java
 *
 * Created on 19 kwiecie 2007, 19:38
 *
 * To change this template, choose Tools | Template Manager
 * and open the template in the editor.
 */

package persistence;

import java.io.Serializable;
import java.math.BigInteger;
import java.util.Collection;
import java.util.Date;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

/**
 * Entity class Contact
 * 
 * @author Tomek
 */
@Entity
@Table(name = "contacts")
@NamedQueries( {
        @NamedQuery(name = "Contact.findByContactId", query = "SELECT c FROM Contact c WHERE c.contactId = :contactId"),
        @NamedQuery(name = "Contact.findByCity", query = "SELECT c FROM Contact c WHERE c.city = :city"),
        @NamedQuery(name = "Contact.findByStreet", query = "SELECT c FROM Contact c WHERE c.street = :street"),
        @NamedQuery(name = "Contact.findByStreetNumber", query = "SELECT c FROM Contact c WHERE c.streetNumber = :streetNumber"),
        @NamedQuery(name = "Contact.findByApartamentNumber", query = "SELECT c FROM Contact c WHERE c.apartamentNumber = :apartamentNumber"),
        @NamedQuery(name = "Contact.findByPhoneNumber", query = "SELECT c FROM Contact c WHERE c.phoneNumber = :phoneNumber"),
        @NamedQuery(name = "Contact.findByChangeStamp", query = "SELECT c FROM Contact c WHERE c.changeStamp = :changeStamp")
    })
public class Contact implements Serializable {

    @Id
    @Column(name = "contact_id", nullable = false)
    @SequenceGenerator(name = "contacts_contact_id_seq", sequenceName = "contacts_contact_id_seq")
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "contacts_contact_id_seq")
    private BigInteger contactId;

    @Column(name = "city", nullable = false)
    private String city;

    @Column(name = "street", nullable = false)
    private String street;

    @Column(name = "street_number", nullable = false)
    private int streetNumber;

    @Column(name = "apartament_number", nullable = false)
    private int apartamentNumber;

    @Column(name = "phone_number", nullable = false)
    private String phoneNumber;

    @Column(name = "change_stamp", insertable = false)
    @Temporal(TemporalType.TIMESTAMP)
    private Date changeStamp;

    @JoinColumn(name = "country_id", referencedColumnName = "country_id")
    @ManyToOne
    private Country countryId;

    @OneToMany(cascade = CascadeType.ALL, mappedBy = "contactId")
    private Collection<Office> officeCollection;

    @OneToMany(cascade = CascadeType.ALL, mappedBy = "contactId")
    private Collection<User> userCollection;
    
    /** Creates a new instance of Contact */
    public Contact() {
    }

    /**
     * Creates a new instance of Contact with the specified values.
     * @param contactId the contactId of the Contact
     */
    public Contact(BigInteger contactId) {
        this.contactId = contactId;
    }

    /**
     * Creates a new instance of Contact with the specified values.
     * @param contactId the contactId of the Contact
     * @param city the city of the Contact
     * @param street the street of the Contact
     * @param streetNumber the streetNumber of the Contact
     * @param apartamentNumber the apartamentNumber of the Contact
     * @param phoneNumber the phoneNumber of the Contact
     * @param changeStamp the changeStamp of the Contact
     */
    public Contact(BigInteger contactId, String city, String street, int streetNumber, int apartamentNumber, String phoneNumber, Date changeStamp) {
        this.contactId = contactId;
        this.city = city;
        this.street = street;
        this.streetNumber = streetNumber;
        this.apartamentNumber = apartamentNumber;
        this.phoneNumber = phoneNumber;
        this.changeStamp = changeStamp;
    }

    /**
     * Gets the contactId of this Contact.
     * @return the contactId
     */
    public BigInteger getContactId() {
        return this.contactId;
    }

    /**
     * Sets the contactId of this Contact to the specified value.
     * @param contactId the new contactId
     */
    public void setContactId(BigInteger contactId) {
        this.contactId = contactId;
    }

    /**
     * Gets the city of this Contact.
     * @return the city
     */
    public String getCity() {
        return this.city;
    }

    /**
     * Sets the city of this Contact to the specified value.
     * @param city the new city
     */
    public void setCity(String city) {
        this.city = city;
    }

    /**
     * Gets the street of this Contact.
     * @return the street
     */
    public String getStreet() {
        return this.street;
    }

    /**
     * Sets the street of this Contact to the specified value.
     * @param street the new street
     */
    public void setStreet(String street) {
        this.street = street;
    }

    /**
     * Gets the streetNumber of this Contact.
     * @return the streetNumber
     */
    public int getStreetNumber() {
        return this.streetNumber;
    }

    /**
     * Sets the streetNumber of this Contact to the specified value.
     * @param streetNumber the new streetNumber
     */
    public void setStreetNumber(int streetNumber) {
        this.streetNumber = streetNumber;
    }

    /**
     * Gets the apartamentNumber of this Contact.
     * @return the apartamentNumber
     */
    public int getApartamentNumber() {
        return this.apartamentNumber;
    }

    /**
     * Sets the apartamentNumber of this Contact to the specified value.
     * @param apartamentNumber the new apartamentNumber
     */
    public void setApartamentNumber(int apartamentNumber) {
        this.apartamentNumber = apartamentNumber;
    }

    /**
     * Gets the phoneNumber of this Contact.
     * @return the phoneNumber
     */
    public String getPhoneNumber() {
        return this.phoneNumber;
    }

    /**
     * Sets the phoneNumber of this Contact to the specified value.
     * @param phoneNumber the new phoneNumber
     */
    public void setPhoneNumber(String phoneNumber) {
        this.phoneNumber = phoneNumber;
    }

    /**
     * Gets the changeStamp of this Contact.
     * @return the changeStamp
     */
    public Date getChangeStamp() {
        return this.changeStamp;
    }

    /**
     * Sets the changeStamp of this Contact to the specified value.
     * @param changeStamp the new changeStamp
     */
    public void setChangeStamp(Date changeStamp) {
        this.changeStamp = changeStamp;
    }

    /**
     * Gets the countryId of this Contact.
     * @return the countryId
     */
    public Country getCountryId() {
        return this.countryId;
    }

    /**
     * Sets the countryId of this Contact to the specified value.
     * @param countryId the new countryId
     */
    public void setCountryId(Country countryId) {
        this.countryId = countryId;
    }

    /**
     * Gets the officeCollection of this Contact.
     * @return the officeCollection
     */
    public Collection<Office> getOfficeCollection() {
        return this.officeCollection;
    }

    /**
     * Sets the officeCollection of this Contact to the specified value.
     * @param officeCollection the new officeCollection
     */
    public void setOfficeCollection(Collection<Office> officeCollection) {
        this.officeCollection = officeCollection;
    }

    /**
     * Gets the userCollection of this Contact.
     * @return the userCollection
     */
    public Collection<User> getUserCollection() {
        return this.userCollection;
    }

    /**
     * Sets the userCollection of this Contact to the specified value.
     * @param userCollection the new userCollection
     */
    public void setUserCollection(Collection<User> userCollection) {
        this.userCollection = userCollection;
    }

    /**
     * Returns a hash code value for the object.  This implementation computes 
     * a hash code value based on the id fields in this object.
     * @return a hash code value for this object.
     */
    @Override
    public int hashCode() {
        int hash = 0;
        hash += (this.contactId != null ? this.contactId.hashCode() : 0);
        return hash;
    }

    /**
     * Determines whether another object is equal to this Contact.  The result is 
     * <code>true</code> if and only if the argument is not null and is a Contact object that 
     * has the same id field values as this object.
     * @param object the reference object with which to compare
     * @return <code>true</code> if this object is the same as the argument;
     * <code>false</code> otherwise.
     */
    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Contact)) {
            return false;
        }
        Contact other = (Contact)object;
        if (this.contactId != other.contactId && (this.contactId == null || !this.contactId.equals(other.contactId))) return false;
        return true;
    }

    /**
     * Returns a string representation of the object.  This implementation constructs 
     * that representation based on the id fields.
     * @return a string representation of the object.
     */
    @Override
    public String toString() {
        return "persistence.Contact[contactId=" + contactId + "]";
    }
    
}
