/*
 * Country.java
 *
 * Created on 19 kwiecie 2007, 19:38
 *
 * To change this template, choose Tools | Template Manager
 * and open the template in the editor.
 */

package persistence;

import java.io.Serializable;
import java.math.BigInteger;
import java.util.Collection;
import java.util.Date;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.xml.bind.annotation.XmlTransient;

/**
 * Entity class Country
 * 
 * @author Tomek
 */
@Entity
@Table(name = "countries")
@NamedQueries( {
        @NamedQuery(name = "Country.findByCountryId", query = "SELECT c FROM Country c WHERE c.countryId = :countryId"),
        @NamedQuery(name = "Country.findByCountryName", query = "SELECT c FROM Country c WHERE c.countryName = :countryName"),
        @NamedQuery(name = "Country.findByChangeStamp", query = "SELECT c FROM Country c WHERE c.changeStamp = :changeStamp")
    })
public class Country implements Serializable {

    @Id
    @Column(name = "country_id", nullable = false)
    private BigInteger countryId;

    @Column(name = "country_name", nullable = false)
    private String countryName;

    @Column(name = "change_stamp", nullable = false)
    @Temporal(TemporalType.TIMESTAMP)
    private Date changeStamp;

    @XmlTransient
    @OneToMany(cascade = CascadeType.ALL, mappedBy = "countryId")
    private Collection<Contact> contactCollection;
    
    /** Creates a new instance of Country */
    public Country() {
    }

    /**
     * Creates a new instance of Country with the specified values.
     * @param countryId the countryId of the Country
     */
    public Country(BigInteger countryId) {
        this.countryId = countryId;
    }

    /**
     * Creates a new instance of Country with the specified values.
     * @param countryId the countryId of the Country
     * @param countryName the countryName of the Country
     * @param changeStamp the changeStamp of the Country
     */
    public Country(BigInteger countryId, String countryName, Date changeStamp) {
        this.countryId = countryId;
        this.countryName = countryName;
        this.changeStamp = changeStamp;
    }

    /**
     * Gets the countryId of this Country.
     * @return the countryId
     */
    public BigInteger getCountryId() {
        return this.countryId;
    }

    /**
     * Sets the countryId of this Country to the specified value.
     * @param countryId the new countryId
     */
    public void setCountryId(BigInteger countryId) {
        this.countryId = countryId;
    }

    /**
     * Gets the countryName of this Country.
     * @return the countryName
     */
    public String getCountryName() {
        return this.countryName;
    }

    /**
     * Sets the countryName of this Country to the specified value.
     * @param countryName the new countryName
     */
    public void setCountryName(String countryName) {
        this.countryName = countryName;
    }

    /**
     * Gets the changeStamp of this Country.
     * @return the changeStamp
     */
    public Date getChangeStamp() {
        return this.changeStamp;
    }

    /**
     * Sets the changeStamp of this Country to the specified value.
     * @param changeStamp the new changeStamp
     */
    public void setChangeStamp(Date changeStamp) {
        this.changeStamp = changeStamp;
    }

    /**
     * Gets the contactCollection of this Country.
     * @return the contactCollection
     */
    @XmlTransient
    public Collection<Contact> getContactCollection() {
        return this.contactCollection;
    }

    /**
     * Sets the contactCollection of this Country to the specified value.
     * @param contactCollection the new contactCollection
     */    
    public void setContactCollection(Collection<Contact> contactCollection) {
        this.contactCollection = contactCollection;
    }

    /**
     * Returns a hash code value for the object.  This implementation computes 
     * a hash code value based on the id fields in this object.
     * @return a hash code value for this object.
     */
    @Override
    public int hashCode() {
        int hash = 0;
        hash += (this.countryId != null ? this.countryId.hashCode() : 0);
        return hash;
    }

    /**
     * Determines whether another object is equal to this Country.  The result is 
     * <code>true</code> if and only if the argument is not null and is a Country object that 
     * has the same id field values as this object.
     * @param object the reference object with which to compare
     * @return <code>true</code> if this object is the same as the argument;
     * <code>false</code> otherwise.
     */
    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Country)) {
            return false;
        }
        Country other = (Country)object;
        if (this.countryId != other.countryId && (this.countryId == null || !this.countryId.equals(other.countryId))) return false;
        return true;
    }

    /**
     * Returns a string representation of the object.  This implementation constructs 
     * that representation based on the id fields.
     * @return a string representation of the object.
     */
    @Override
    public String toString() {
        return "persistence.Country[countryId=" + countryId + "]";
    }
    
}
