/*
 * DeliveriesOffices.java
 *
 * Created on 19 kwiecie 2007, 19:38
 *
 * To change this template, choose Tools | Template Manager
 * and open the template in the editor.
 */

package persistence;

import java.io.Serializable;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.EmbeddedId;
import javax.persistence.Entity;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

/**
 * Entity class DeliveriesOffices
 * 
 * @author Tomek
 */
@Entity
@Table(name = "deliveries_offices")
@NamedQueries( {
        @NamedQuery(name = "DeliveriesOffices.findByDeliveryId", query = "SELECT d FROM DeliveriesOffices d WHERE d.deliveriesOfficesPK.deliveryId = :deliveryId"),
        @NamedQuery(name = "DeliveriesOffices.findByOfficeId", query = "SELECT d FROM DeliveriesOffices d WHERE d.deliveriesOfficesPK.officeId = :officeId"),
        @NamedQuery(name = "DeliveriesOffices.findByExistedTime", query = "SELECT d FROM DeliveriesOffices d WHERE d.deliveriesOfficesPK.existedTime = :existedTime"),
        @NamedQuery(name = "DeliveriesOffices.findByChangeStamp", query = "SELECT d FROM DeliveriesOffices d WHERE d.changeStamp = :changeStamp")
    })
public class DeliveriesOffices implements Serializable {

    /**
     * EmbeddedId primary key field
     */
    @EmbeddedId
    protected DeliveriesOfficesPK deliveriesOfficesPK;

    @Column(name = "change_stamp")
    @Temporal(TemporalType.TIMESTAMP)
    private Date changeStamp;

    @JoinColumn(name = "delivery_id", referencedColumnName = "delivery_id", insertable = false, updatable = false)
    @ManyToOne
    private Delivery delivery;

    @JoinColumn(name = "office_id", referencedColumnName = "office_id", insertable = false, updatable = false)
    @ManyToOne
    private Office office;
    
    /** Creates a new instance of DeliveriesOffices */
    public DeliveriesOffices() {
    }

    /**
     * Creates a new instance of DeliveriesOffices with the specified values.
     * @param deliveriesOfficesPK the deliveriesOfficesPK of the DeliveriesOffices
     */
    public DeliveriesOffices(DeliveriesOfficesPK deliveriesOfficesPK) {
        this.deliveriesOfficesPK = deliveriesOfficesPK;
    }

    /**
     * Creates a new instance of DeliveriesOfficesPK with the specified values.
     * @param existedTime the existedTime of the DeliveriesOfficesPK
     * @param officeId the officeId of the DeliveriesOfficesPK
     * @param deliveryId the deliveryId of the DeliveriesOfficesPK
     */
    public DeliveriesOffices(Date existedTime, long officeId, long deliveryId) {
        this.deliveriesOfficesPK = new DeliveriesOfficesPK(existedTime, officeId, deliveryId);
    }

    /**
     * Gets the deliveriesOfficesPK of this DeliveriesOffices.
     * @return the deliveriesOfficesPK
     */
    public DeliveriesOfficesPK getDeliveriesOfficesPK() {
        return this.deliveriesOfficesPK;
    }

    /**
     * Sets the deliveriesOfficesPK of this DeliveriesOffices to the specified value.
     * @param deliveriesOfficesPK the new deliveriesOfficesPK
     */
    public void setDeliveriesOfficesPK(DeliveriesOfficesPK deliveriesOfficesPK) {
        this.deliveriesOfficesPK = deliveriesOfficesPK;
    }

    /**
     * Gets the changeStamp of this DeliveriesOffices.
     * @return the changeStamp
     */
    public Date getChangeStamp() {
        return this.changeStamp;
    }

    /**
     * Sets the changeStamp of this DeliveriesOffices to the specified value.
     * @param changeStamp the new changeStamp
     */
    public void setChangeStamp(Date changeStamp) {
        this.changeStamp = changeStamp;
    }

    /**
     * Gets the delivery of this DeliveriesOffices.
     * @return the delivery
     */
    public Delivery getDelivery() {
        return this.delivery;
    }

    /**
     * Sets the delivery of this DeliveriesOffices to the specified value.
     * @param delivery the new delivery
     */
    public void setDelivery(Delivery delivery) {
        this.delivery = delivery;
    }

    /**
     * Gets the office of this DeliveriesOffices.
     * @return the office
     */
    public Office getOffice() {
        return this.office;
    }

    /**
     * Sets the office of this DeliveriesOffices to the specified value.
     * @param office the new office
     */
    public void setOffice(Office office) {
        this.office = office;
    }

    /**
     * Returns a hash code value for the object.  This implementation computes 
     * a hash code value based on the id fields in this object.
     * @return a hash code value for this object.
     */
    @Override
    public int hashCode() {
        int hash = 0;
        hash += (this.deliveriesOfficesPK != null ? this.deliveriesOfficesPK.hashCode() : 0);
        return hash;
    }

    /**
     * Determines whether another object is equal to this DeliveriesOffices.  The result is 
     * <code>true</code> if and only if the argument is not null and is a DeliveriesOffices object that 
     * has the same id field values as this object.
     * @param object the reference object with which to compare
     * @return <code>true</code> if this object is the same as the argument;
     * <code>false</code> otherwise.
     */
    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof DeliveriesOffices)) {
            return false;
        }
        DeliveriesOffices other = (DeliveriesOffices)object;
        if (this.deliveriesOfficesPK != other.deliveriesOfficesPK && (this.deliveriesOfficesPK == null || !this.deliveriesOfficesPK.equals(other.deliveriesOfficesPK))) return false;
        return true;
    }

    /**
     * Returns a string representation of the object.  This implementation constructs 
     * that representation based on the id fields.
     * @return a string representation of the object.
     */
    @Override
    public String toString() {
        return "persistence.DeliveriesOffices[deliveriesOfficesPK=" + deliveriesOfficesPK + "]";
    }
    
}
