/*
 * Delivery.java
 *
 * Created on 19 kwiecie 2007, 19:38
 *
 * To change this template, choose Tools | Template Manager
 * and open the template in the editor.
 */

package persistence;

import java.io.Serializable;
import java.math.BigInteger;
import java.util.Collection;
import java.util.Date;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

/**
 * Entity class Delivery
 * 
 * @author Tomek
 */
@Entity
@Table(name = "deliveries")
@NamedQueries( {
        @NamedQuery(name = "Delivery.findByDeliveryId", query = "SELECT d FROM Delivery d WHERE d.deliveryId = :deliveryId"),
        @NamedQuery(name = "Delivery.findBySendDate", query = "SELECT d FROM Delivery d WHERE d.sendDate = :sendDate"),
        @NamedQuery(name = "Delivery.findByPlannedReceiveDate", query = "SELECT d FROM Delivery d WHERE d.plannedReceiveDate = :plannedReceiveDate"),
        @NamedQuery(name = "Delivery.findByChangeStamp", query = "SELECT d FROM Delivery d WHERE d.changeStamp = :changeStamp")
    })
public class Delivery implements Serializable {

    @Id
    @Column(name = "delivery_id", nullable = false)
    private BigInteger deliveryId;

    @Column(name = "send_date", nullable = false)
    @Temporal(TemporalType.TIMESTAMP)
    private Date sendDate;

    @Column(name = "planned_receive_date", nullable = false)
    @Temporal(TemporalType.TIMESTAMP)
    private Date plannedReceiveDate;

    @Column(name = "change_stamp")
    @Temporal(TemporalType.TIMESTAMP)
    private Date changeStamp;

    @OneToMany(cascade = CascadeType.ALL, mappedBy = "delivery")
    private Collection<DeliveriesOffices> deliveriesOfficesCollection;

    @JoinColumn(name = "priority_id", referencedColumnName = "priority_id")
    @ManyToOne
    private DeliveryPriority priorityId;

    @JoinColumn(name = "sender_id", referencedColumnName = "user_id")
    @ManyToOne
    private User senderId;

    @JoinColumn(name = "receiver_id", referencedColumnName = "user_id")
    @ManyToOne
    private User receiverId;

    @JoinColumn(name = "courier_id", referencedColumnName = "user_id")
    @ManyToOne
    private User courierId;
    
    /** Creates a new instance of Delivery */
    public Delivery() {
    }

    /**
     * Creates a new instance of Delivery with the specified values.
     * @param deliveryId the deliveryId of the Delivery
     */
    public Delivery(BigInteger deliveryId) {
        this.deliveryId = deliveryId;
    }

    /**
     * Creates a new instance of Delivery with the specified values.
     * @param deliveryId the deliveryId of the Delivery
     * @param sendDate the sendDate of the Delivery
     * @param plannedReceiveDate the plannedReceiveDate of the Delivery
     */
    public Delivery(BigInteger deliveryId, Date sendDate, Date plannedReceiveDate) {
        this.deliveryId = deliveryId;
        this.sendDate = sendDate;
        this.plannedReceiveDate = plannedReceiveDate;
    }

    /**
     * Gets the deliveryId of this Delivery.
     * @return the deliveryId
     */
    public BigInteger getDeliveryId() {
        return this.deliveryId;
    }

    /**
     * Sets the deliveryId of this Delivery to the specified value.
     * @param deliveryId the new deliveryId
     */
    public void setDeliveryId(BigInteger deliveryId) {
        this.deliveryId = deliveryId;
    }

    /**
     * Gets the sendDate of this Delivery.
     * @return the sendDate
     */
    public Date getSendDate() {
        return this.sendDate;
    }

    /**
     * Sets the sendDate of this Delivery to the specified value.
     * @param sendDate the new sendDate
     */
    public void setSendDate(Date sendDate) {
        this.sendDate = sendDate;
    }

    /**
     * Gets the plannedReceiveDate of this Delivery.
     * @return the plannedReceiveDate
     */
    public Date getPlannedReceiveDate() {
        return this.plannedReceiveDate;
    }

    /**
     * Sets the plannedReceiveDate of this Delivery to the specified value.
     * @param plannedReceiveDate the new plannedReceiveDate
     */
    public void setPlannedReceiveDate(Date plannedReceiveDate) {
        this.plannedReceiveDate = plannedReceiveDate;
    }

    /**
     * Gets the changeStamp of this Delivery.
     * @return the changeStamp
     */
    public Date getChangeStamp() {
        return this.changeStamp;
    }

    /**
     * Sets the changeStamp of this Delivery to the specified value.
     * @param changeStamp the new changeStamp
     */
    public void setChangeStamp(Date changeStamp) {
        this.changeStamp = changeStamp;
    }

    /**
     * Gets the deliveriesOfficesCollection of this Delivery.
     * @return the deliveriesOfficesCollection
     */
    public Collection<DeliveriesOffices> getDeliveriesOfficesCollection() {
        return this.deliveriesOfficesCollection;
    }

    /**
     * Sets the deliveriesOfficesCollection of this Delivery to the specified value.
     * @param deliveriesOfficesCollection the new deliveriesOfficesCollection
     */
    public void setDeliveriesOfficesCollection(Collection<DeliveriesOffices> deliveriesOfficesCollection) {
        this.deliveriesOfficesCollection = deliveriesOfficesCollection;
    }

    /**
     * Gets the priorityId of this Delivery.
     * @return the priorityId
     */
    public DeliveryPriority getPriorityId() {
        return this.priorityId;
    }

    /**
     * Sets the priorityId of this Delivery to the specified value.
     * @param priorityId the new priorityId
     */
    public void setPriorityId(DeliveryPriority priorityId) {
        this.priorityId = priorityId;
    }

    /**
     * Gets the senderId of this Delivery.
     * @return the senderId
     */
    public User getSenderId() {
        return this.senderId;
    }

    /**
     * Sets the senderId of this Delivery to the specified value.
     * @param senderId the new senderId
     */
    public void setSenderId(User senderId) {
        this.senderId = senderId;
    }

    /**
     * Gets the receiverId of this Delivery.
     * @return the receiverId
     */
    public User getReceiverId() {
        return this.receiverId;
    }

    /**
     * Sets the receiverId of this Delivery to the specified value.
     * @param receiverId the new receiverId
     */
    public void setReceiverId(User receiverId) {
        this.receiverId = receiverId;
    }

    /**
     * Gets the courierId of this Delivery.
     * @return the courierId
     */
    public User getCourierId() {
        return this.courierId;
    }

    /**
     * Sets the courierId of this Delivery to the specified value.
     * @param courierId the new courierId
     */
    public void setCourierId(User courierId) {
        this.courierId = courierId;
    }

    /**
     * Returns a hash code value for the object.  This implementation computes 
     * a hash code value based on the id fields in this object.
     * @return a hash code value for this object.
     */
    @Override
    public int hashCode() {
        int hash = 0;
        hash += (this.deliveryId != null ? this.deliveryId.hashCode() : 0);
        return hash;
    }

    /**
     * Determines whether another object is equal to this Delivery.  The result is 
     * <code>true</code> if and only if the argument is not null and is a Delivery object that 
     * has the same id field values as this object.
     * @param object the reference object with which to compare
     * @return <code>true</code> if this object is the same as the argument;
     * <code>false</code> otherwise.
     */
    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Delivery)) {
            return false;
        }
        Delivery other = (Delivery)object;
        if (this.deliveryId != other.deliveryId && (this.deliveryId == null || !this.deliveryId.equals(other.deliveryId))) return false;
        return true;
    }

    /**
     * Returns a string representation of the object.  This implementation constructs 
     * that representation based on the id fields.
     * @return a string representation of the object.
     */
    @Override
    public String toString() {
        return "persistence.Delivery[deliveryId=" + deliveryId + "]";
    }
    
}
