/*
 * DeliveryPriority.java
 *
 * Created on 19 kwiecie 2007, 19:38
 *
 * To change this template, choose Tools | Template Manager
 * and open the template in the editor.
 */

package persistence;

import java.io.Serializable;
import java.math.BigInteger;
import java.util.Collection;
import java.util.Date;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

/**
 * Entity class DeliveryPriority
 * 
 * @author Tomek
 */
@Entity
@Table(name = "delivery_priorities")
@NamedQueries( {
        @NamedQuery(name = "DeliveryPriority.findByPriorityId", query = "SELECT d FROM DeliveryPriority d WHERE d.priorityId = :priorityId"),
        @NamedQuery(name = "DeliveryPriority.findByPriorityName", query = "SELECT d FROM DeliveryPriority d WHERE d.priorityName = :priorityName"),
        @NamedQuery(name = "DeliveryPriority.findByDeliveryDays", query = "SELECT d FROM DeliveryPriority d WHERE d.deliveryDays = :deliveryDays"),
        @NamedQuery(name = "DeliveryPriority.findByChangeStamp", query = "SELECT d FROM DeliveryPriority d WHERE d.changeStamp = :changeStamp")
    })
public class DeliveryPriority implements Serializable {

    @Id
    @Column(name = "priority_id", nullable = false)
    private BigInteger priorityId;

    @Column(name = "priority_name", nullable = false)
    private String priorityName;

    @Column(name = "delivery_days", nullable = false)
    private int deliveryDays;

    @Column(name = "change_stamp")
    @Temporal(TemporalType.TIMESTAMP)
    private Date changeStamp;

    @OneToMany(cascade = CascadeType.ALL, mappedBy = "priorityId")
    private Collection<Delivery> deliveryCollection;
    
    /** Creates a new instance of DeliveryPriority */
    public DeliveryPriority() {
    }

    /**
     * Creates a new instance of DeliveryPriority with the specified values.
     * @param priorityId the priorityId of the DeliveryPriority
     */
    public DeliveryPriority(BigInteger priorityId) {
        this.priorityId = priorityId;
    }

    /**
     * Creates a new instance of DeliveryPriority with the specified values.
     * @param priorityId the priorityId of the DeliveryPriority
     * @param priorityName the priorityName of the DeliveryPriority
     * @param deliveryDays the deliveryDays of the DeliveryPriority
     */
    public DeliveryPriority(BigInteger priorityId, String priorityName, int deliveryDays) {
        this.priorityId = priorityId;
        this.priorityName = priorityName;
        this.deliveryDays = deliveryDays;
    }

    /**
     * Gets the priorityId of this DeliveryPriority.
     * @return the priorityId
     */
    public BigInteger getPriorityId() {
        return this.priorityId;
    }

    /**
     * Sets the priorityId of this DeliveryPriority to the specified value.
     * @param priorityId the new priorityId
     */
    public void setPriorityId(BigInteger priorityId) {
        this.priorityId = priorityId;
    }

    /**
     * Gets the priorityName of this DeliveryPriority.
     * @return the priorityName
     */
    public String getPriorityName() {
        return this.priorityName;
    }

    /**
     * Sets the priorityName of this DeliveryPriority to the specified value.
     * @param priorityName the new priorityName
     */
    public void setPriorityName(String priorityName) {
        this.priorityName = priorityName;
    }

    /**
     * Gets the deliveryDays of this DeliveryPriority.
     * @return the deliveryDays
     */
    public int getDeliveryDays() {
        return this.deliveryDays;
    }

    /**
     * Sets the deliveryDays of this DeliveryPriority to the specified value.
     * @param deliveryDays the new deliveryDays
     */
    public void setDeliveryDays(int deliveryDays) {
        this.deliveryDays = deliveryDays;
    }

    /**
     * Gets the changeStamp of this DeliveryPriority.
     * @return the changeStamp
     */
    public Date getChangeStamp() {
        return this.changeStamp;
    }

    /**
     * Sets the changeStamp of this DeliveryPriority to the specified value.
     * @param changeStamp the new changeStamp
     */
    public void setChangeStamp(Date changeStamp) {
        this.changeStamp = changeStamp;
    }

    /**
     * Gets the deliveryCollection of this DeliveryPriority.
     * @return the deliveryCollection
     */
    public Collection<Delivery> getDeliveryCollection() {
        return this.deliveryCollection;
    }

    /**
     * Sets the deliveryCollection of this DeliveryPriority to the specified value.
     * @param deliveryCollection the new deliveryCollection
     */
    public void setDeliveryCollection(Collection<Delivery> deliveryCollection) {
        this.deliveryCollection = deliveryCollection;
    }

    /**
     * Returns a hash code value for the object.  This implementation computes 
     * a hash code value based on the id fields in this object.
     * @return a hash code value for this object.
     */
    @Override
    public int hashCode() {
        int hash = 0;
        hash += (this.priorityId != null ? this.priorityId.hashCode() : 0);
        return hash;
    }

    /**
     * Determines whether another object is equal to this DeliveryPriority.  The result is 
     * <code>true</code> if and only if the argument is not null and is a DeliveryPriority object that 
     * has the same id field values as this object.
     * @param object the reference object with which to compare
     * @return <code>true</code> if this object is the same as the argument;
     * <code>false</code> otherwise.
     */
    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof DeliveryPriority)) {
            return false;
        }
        DeliveryPriority other = (DeliveryPriority)object;
        if (this.priorityId != other.priorityId && (this.priorityId == null || !this.priorityId.equals(other.priorityId))) return false;
        return true;
    }

    /**
     * Returns a string representation of the object.  This implementation constructs 
     * that representation based on the id fields.
     * @return a string representation of the object.
     */
    @Override
    public String toString() {
        return "persistence.DeliveryPriority[priorityId=" + priorityId + "]";
    }
    
}
