/*
 * Office.java
 *
 * Created on 19 kwiecie 2007, 19:38
 *
 * To change this template, choose Tools | Template Manager
 * and open the template in the editor.
 */

package persistence;

import java.io.Serializable;
import java.math.BigInteger;
import java.util.Collection;
import java.util.Date;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

/**
 * Entity class Office
 * 
 * @author Tomek
 */
@Entity
@Table(name = "offices")
@NamedQueries( {
        @NamedQuery(name = "Office.findByOfficeId", query = "SELECT o FROM Office o WHERE o.officeId = :officeId"),
        @NamedQuery(name = "Office.findByOfficeName", query = "SELECT o FROM Office o WHERE o.officeName = :officeName"),
        @NamedQuery(name = "Office.findByChangeStamp", query = "SELECT o FROM Office o WHERE o.changeStamp = :changeStamp")
    })
public class Office implements Serializable {

    @Id
    @Column(name = "office_id", nullable = false)
    private BigInteger officeId;

    @Column(name = "office_name", nullable = false)
    private String officeName;

    @Column(name = "change_stamp")
    @Temporal(TemporalType.TIMESTAMP)
    private Date changeStamp;

    @OneToMany(cascade = CascadeType.ALL, mappedBy = "office")
    private Collection<DeliveriesOffices> deliveriesOfficesCollection;

    @JoinColumn(name = "contact_id", referencedColumnName = "contact_id")
    @ManyToOne
    private Contact contactId;

    @OneToMany(mappedBy = "officeId")
    private Collection<User> userCollection;
    
    /** Creates a new instance of Office */
    public Office() {
    }

    /**
     * Creates a new instance of Office with the specified values.
     * @param officeId the officeId of the Office
     */
    public Office(BigInteger officeId) {
        this.officeId = officeId;
    }

    /**
     * Creates a new instance of Office with the specified values.
     * @param officeId the officeId of the Office
     * @param officeName the officeName of the Office
     */
    public Office(BigInteger officeId, String officeName) {
        this.officeId = officeId;
        this.officeName = officeName;
    }

    /**
     * Gets the officeId of this Office.
     * @return the officeId
     */
    public BigInteger getOfficeId() {
        return this.officeId;
    }

    /**
     * Sets the officeId of this Office to the specified value.
     * @param officeId the new officeId
     */
    public void setOfficeId(BigInteger officeId) {
        this.officeId = officeId;
    }

    /**
     * Gets the officeName of this Office.
     * @return the officeName
     */
    public String getOfficeName() {
        return this.officeName;
    }

    /**
     * Sets the officeName of this Office to the specified value.
     * @param officeName the new officeName
     */
    public void setOfficeName(String officeName) {
        this.officeName = officeName;
    }

    /**
     * Gets the changeStamp of this Office.
     * @return the changeStamp
     */
    public Date getChangeStamp() {
        return this.changeStamp;
    }

    /**
     * Sets the changeStamp of this Office to the specified value.
     * @param changeStamp the new changeStamp
     */
    public void setChangeStamp(Date changeStamp) {
        this.changeStamp = changeStamp;
    }

    /**
     * Gets the deliveriesOfficesCollection of this Office.
     * @return the deliveriesOfficesCollection
     */
    public Collection<DeliveriesOffices> getDeliveriesOfficesCollection() {
        return this.deliveriesOfficesCollection;
    }

    /**
     * Sets the deliveriesOfficesCollection of this Office to the specified value.
     * @param deliveriesOfficesCollection the new deliveriesOfficesCollection
     */
    public void setDeliveriesOfficesCollection(Collection<DeliveriesOffices> deliveriesOfficesCollection) {
        this.deliveriesOfficesCollection = deliveriesOfficesCollection;
    }

    /**
     * Gets the contactId of this Office.
     * @return the contactId
     */
    public Contact getContactId() {
        return this.contactId;
    }

    /**
     * Sets the contactId of this Office to the specified value.
     * @param contactId the new contactId
     */
    public void setContactId(Contact contactId) {
        this.contactId = contactId;
    }

    /**
     * Gets the userCollection of this Office.
     * @return the userCollection
     */
    public Collection<User> getUserCollection() {
        return this.userCollection;
    }

    /**
     * Sets the userCollection of this Office to the specified value.
     * @param userCollection the new userCollection
     */
    public void setUserCollection(Collection<User> userCollection) {
        this.userCollection = userCollection;
    }

    /**
     * Returns a hash code value for the object.  This implementation computes 
     * a hash code value based on the id fields in this object.
     * @return a hash code value for this object.
     */
    @Override
    public int hashCode() {
        int hash = 0;
        hash += (this.officeId != null ? this.officeId.hashCode() : 0);
        return hash;
    }

    /**
     * Determines whether another object is equal to this Office.  The result is 
     * <code>true</code> if and only if the argument is not null and is a Office object that 
     * has the same id field values as this object.
     * @param object the reference object with which to compare
     * @return <code>true</code> if this object is the same as the argument;
     * <code>false</code> otherwise.
     */
    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Office)) {
            return false;
        }
        Office other = (Office)object;
        if (this.officeId != other.officeId && (this.officeId == null || !this.officeId.equals(other.officeId))) return false;
        return true;
    }

    /**
     * Returns a string representation of the object.  This implementation constructs 
     * that representation based on the id fields.
     * @return a string representation of the object.
     */
    @Override
    public String toString() {
        return "persistence.Office[officeId=" + officeId + "]";
    }
    
}
