/*
 * User.java
 *
 * Created on 19 kwiecie 2007, 19:38
 *
 * To change this template, choose Tools | Template Manager
 * and open the template in the editor.
 */

package persistence;

import java.io.Serializable;
import java.math.BigInteger;
import java.util.Collection;
import java.util.Date;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.DiscriminatorColumn;
import javax.persistence.DiscriminatorType;
import javax.persistence.DiscriminatorValue;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Inheritance;
import javax.persistence.InheritanceType;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.PrimaryKeyJoinColumn;
import javax.persistence.SecondaryTable;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.xml.bind.annotation.XmlRootElement;

/**
 * Entity class User
 * 
 * @author Tomek
 */
@Entity
@Table(name = "users")
@SecondaryTable(name="accounts",pkJoinColumns={@PrimaryKeyJoinColumn(name="user_id", referencedColumnName="user_id")})
@DiscriminatorValue("1")
@Inheritance(strategy=InheritanceType.SINGLE_TABLE)
@DiscriminatorColumn(name="role_id", discriminatorType=DiscriminatorType.STRING)

@NamedQueries( {
        @NamedQuery(name = "User.findByUserId", query = "SELECT u FROM User u WHERE u.userId = :userId"),
        @NamedQuery(name = "User.findByName", query = "SELECT u FROM User u WHERE u.name = :name"),
        @NamedQuery(name = "User.findBySurname", query = "SELECT u FROM User u WHERE u.surname = :surname"),
        @NamedQuery(name = "User.findByChangeStamp", query = "SELECT u FROM User u WHERE u.changeStamp = :changeStamp")  ,
        @NamedQuery(name = "User.findNewOrModified", query = "SELECT u FROM User u WHERE u.changeStamp BETWEEN :fromChangeStamp AND :toChangeStamp")
    })
@XmlRootElement()
public class User implements Serializable {

    @Id
    @Column(name = "user_id", nullable = false)
    @SequenceGenerator(name="users_user_id_seq", sequenceName="users_user_id_seq")
    @GeneratedValue(strategy=GenerationType.SEQUENCE, generator="users_user_id_seq")
    private BigInteger userId;

    @Column(name = "name", nullable = false)
    private String name;

    @Column(name = "surname", nullable = false)
    private String surname;
    
    @Column(table= "accounts", name="login")
    private String login;
    
    @Column(table= "accounts", name="password")
    private String password;
            
    @Column(name = "change_stamp",insertable=false)
    @Temporal(TemporalType.TIMESTAMP)
    private Date changeStamp;

    @JoinColumn(name = "contact_id", referencedColumnName = "contact_id")
    @ManyToOne(cascade= CascadeType.ALL)
    private Contact contactId;

    @JoinColumn(name = "office_id", referencedColumnName = "office_id")
    @ManyToOne
    private Office officeId;

    @OneToMany(cascade = CascadeType.ALL, mappedBy = "senderId")
    private Collection<Delivery> deliveryCollection;

    @OneToMany(cascade = CascadeType.ALL, mappedBy = "receiverId")
    private Collection<Delivery> deliveryCollection1;

    @OneToMany(cascade = CascadeType.ALL, mappedBy = "courierId")
    private Collection<Delivery> deliveryCollection2;
    
    /** Creates a new instance of User */
    public User() {
    }

    /**
     * Creates a new instance of User with the specified values.
     * @param userId the userId of the User
     */
    public User(BigInteger userId) {
        this.userId = userId;
    }

    /**
     * Creates a new instance of User with the specified values.
     * @param userId the userId of the User
     * @param name the name of the User
     * @param surname the surname of the User
     * @param changeStamp the changeStamp of the User
     */
    public User(BigInteger userId, String name, String surname, Date changeStamp) {
        this.userId = userId;
        this.name = name;
        this.surname = surname;
        this.changeStamp = changeStamp;
    }

    /**
     * Gets the userId of this User.
     * @return the userId
     */
    public BigInteger getUserId() {
        return this.userId;
    }

    /**
     * Sets the userId of this User to the specified value.
     * @param userId the new userId
     */
    public void setUserId(BigInteger userId) {
        this.userId = userId;
    }

    /**
     * Gets the name of this User.
     * @return the name
     */
    public String getName() {
        return this.name;
    }

    /**
     * Sets the name of this User to the specified value.
     * @param name the new name
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * Gets the surname of this User.
     * @return the surname
     */
    public String getSurname() {
        return this.surname;
    }

    /**
     * Sets the surname of this User to the specified value.
     * @param surname the new surname
     */
    public void setSurname(String surname) {
        this.surname = surname;
    }

    /**
     * Gets the changeStamp of this User.
     * @return the changeStamp
     */
    public Date getChangeStamp() {
        return this.changeStamp;
    }

    /**
     * Sets the changeStamp of this User to the specified value.
     * @param changeStamp the new changeStamp
     */
    public void setChangeStamp(Date changeStamp) {
        this.changeStamp = changeStamp;
    }

    /**
     * Gets the contactId of this User.
     * @return the contactId
     */
    public Contact getContactId() {
        return this.contactId;
    }

    /**
     * Sets the contactId of this User to the specified value.
     * @param contactId the new contactId
     */
    public void setContactId(Contact contactId) {
        this.contactId = contactId;
    }

    /**
     * Gets the officeId of this User.
     * @return the officeId
     */
    public Office getOfficeId() {
        return this.officeId;
    }

    /**
     * Sets the officeId of this User to the specified value.
     * @param officeId the new officeId
     */
    public void setOfficeId(Office officeId) {
        this.officeId = officeId;
    }

    /**
     * Gets the deliveryCollection of this User.
     * @return the deliveryCollection
     */
    public Collection<Delivery> getDeliveryCollection() {
        return this.deliveryCollection;
    }

    /**
     * Sets the deliveryCollection of this User to the specified value.
     * @param deliveryCollection the new deliveryCollection
     */
    public void setDeliveryCollection(Collection<Delivery> deliveryCollection) {
        this.deliveryCollection = deliveryCollection;
    }

    /**
     * Gets the deliveryCollection1 of this User.
     * @return the deliveryCollection1
     */
    public Collection<Delivery> getDeliveryCollection1() {
        return this.deliveryCollection1;
    }

    /**
     * Sets the deliveryCollection1 of this User to the specified value.
     * @param deliveryCollection1 the new deliveryCollection1
     */
    public void setDeliveryCollection1(Collection<Delivery> deliveryCollection1) {
        this.deliveryCollection1 = deliveryCollection1;
    }

    /**
     * Gets the deliveryCollection2 of this User.
     * @return the deliveryCollection2
     */
    public Collection<Delivery> getDeliveryCollection2() {
        return this.deliveryCollection2;
    }

    /**
     * Sets the deliveryCollection2 of this User to the specified value.
     * @param deliveryCollection2 the new deliveryCollection2
     */
    public void setDeliveryCollection2(Collection<Delivery> deliveryCollection2) {
        this.deliveryCollection2 = deliveryCollection2;
    }

    /**
     * Returns a hash code value for the object.  This implementation computes 
     * a hash code value based on the id fields in this object.
     * @return a hash code value for this object.
     */
    @Override
    public int hashCode() {
        int hash = 0;
        hash += (this.userId != null ? this.userId.hashCode() : 0);
        return hash;
    }

    /**
     * Determines whether another object is equal to this User.  The result is 
     * <code>true</code> if and only if the argument is not null and is a User object that 
     * has the same id field values as this object.
     * @param object the reference object with which to compare
     * @return <code>true</code> if this object is the same as the argument;
     * <code>false</code> otherwise.
     */
    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof User)) {
            return false;
        }
        User other = (User)object;
        if (this.userId != other.userId && (this.userId == null || !this.userId.equals(other.userId))) return false;
        return true;
    }

    /**
     * Returns a string representation of the object.  This implementation constructs 
     * that representation based on the id fields.
     * @return a string representation of the object.
     */
    @Override
    public String toString() {
        return "persistence.User[userId=" + userId + "]";
    }

    public String getLogin() {
        return login;
    }

    public void setLogin(String login) {
        this.login = login;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }
    
}
